@@ -126,7 +126,7 @@ format_variables_acs <- function(variables) {
 }
 
 load_data_acs <- function(geography, formatted_variables, key, year, state = NULL,
-                          county = NULL, survey, show_call = FALSE) {
+                          county = NULL, zcta = NULL, survey, show_call = FALSE) {
 
   base <- paste("https://api.census.gov/data",
                   as.character(year), "acs",
@@ -206,7 +206,17 @@ load_data_acs <- function(geography, formatted_variables, key, year, state = NUL
 
   }
 
-  else {
+  else if (!is.null(zcta))  {
+
+    for_area <- paste0(zcta, collapse = ",")
+
+    vars_to_get <- paste0(formatted_variables, ",NAME")
+
+    call <- GET(base, query = list(get = vars_to_get,
+                                   "for" = paste0(geography, ":", for_area),
+                                   key = key))
+
+  } else {
 
     vars_to_get <- paste0(formatted_variables, ",NAME")
 
@@ -440,6 +450,11 @@ load_data_decennial <- function(geography, variables, key, year, sumfile,
   id_vars <- names(dat)[! names(dat) %in% v2]
 
   # Paste into a GEOID column
+  # Apply tract band-aid (GH issue #317)
+  if ("tract" %in% id_vars && year == 2000) {
+    dat$tract <- stringr::str_pad(dat$tract, 6, "right", "0")
+  }
+
   dat$GEOID <- do.call(paste0, dat[id_vars])
 
 
@@ -651,6 +666,9 @@ load_data_estimates <- function(geography, product = NULL, variables = NULL, key
 
 load_data_pums <- function(variables, state, puma, key, year, survey, recode, show_call) {
 
+  # for which years is data dictionary available in pums_variables?
+  # we'll use this a couple times later on
+  recode_years <- 2017:2019
 
   var <- paste0(variables, collapse = ",")
 
@@ -757,8 +775,8 @@ load_data_pums <- function(variables, state, puma, key, year, survey, recode, sh
   # necessary to match data dictionary codes and
   # convert variables to numeric according to data dictionary
 
-  # But wait, this only works when the serial numbers are correctly returned and and we have variable metadata in pums_variables
-  if (year %in% c(2017, 2018)) {
+  # Only works for years included in pums_variables data dictionary
+  if (year %in% recode_years) {
     var_val_length <- pums_variables_filter %>%
       filter(!is.na(.data$val_length)) %>%
       distinct(.data$var_code, .data$val_length, .data$val_na)
@@ -800,8 +818,8 @@ load_data_pums <- function(variables, state, puma, key, year, survey, recode, sh
   # Do you want to return value labels also?
   if (recode) {
 
-    # Only works for 2017 because it's the only year included in pums_variables for now
-    if (year %in% 2017:2018) {
+    # Only works for years included in pums_variables data dictionary
+    if (year %in% recode_years) {
       var_lookup <- pums_variables_filter %>%
         select(.data$var_code, val = .data$val_min, .data$val_label)
 
@@ -856,7 +874,9 @@ load_data_pums <- function(variables, state, puma, key, year, survey, recode, sh
       dat <- dat %>%
         left_join(recoded_wide, by = c("SERIALNO", "SPORDER"))
     } else {
-      message("Recoding is currently only supported for 2017 and 2018 1-year and 5-year data. Returning original data only.")
+      message(paste("Recoding is currently supported for",
+                    min(recode_years), "-", max(recode_years),
+                    "data. Returning original data only."))
       }
     }
   return(dat)
